Quick installation guide
========================

It is assumed that the `python <http://python.org>`_ version 3.x  and `bower <http://bower.io/>`_ are already installed on your computer.

#. Download `MySmile <http://mysmile.com.ua>`_  and unpack it to the project’s directory
#. Install with one command: :command:`$ make install` 
#. While in the project directory run the following command on the terminal: :command:`$ python3 manage.py runserver`

Now your website is available on `<http://127.0.0.1:8000>`_, link to admin page is `<http://127.0.0.1:8000/admin>`_. Log in with default credentials: 
  
* login: *test* 
* password: *test*
